Skip to contents

Downloads and combines Keystone assessment data for multiple school years.

Usage

fetch_keystone_multi(
  end_years,
  level = "school",
  tidy = TRUE,
  use_cache = TRUE
)

Arguments

end_years

Vector of school year ends (e.g., c(2022, 2023, 2024))

level

Data aggregation level: "school" (default), "district", or "state"

tidy

If TRUE (default), returns data in long format.

use_cache

If TRUE (default), uses locally cached data when available.

Value

Combined data frame with Keystone data for all requested years

Examples

if (FALSE) { # \dontrun{
# Get 5 years of data
keystone_multi <- fetch_keystone_multi(2019:2025)

# Note: 2020 will be skipped (COVID)
} # }