Downloads and combines enrollment data for multiple school years.
Usage
fetch_enr_years(years, tidy = TRUE, use_cache = TRUE)
Arguments
- years
Vector of school year ends (e.g., c(2020, 2021, 2022, 2023, 2024))
- tidy
If TRUE (default), returns data in long (tidy) format
- use_cache
If TRUE (default), uses locally cached data when available
Value
Data frame with combined enrollment data for all years
Examples
if (FALSE) { # \dontrun{
# Get 5 years of enrollment data
enr_multi <- fetch_enr_years(2021:2025)
} # }